@@ -7,38 +7,42 @@ simulate(
               t0=0,
               rprocess=euler.sim(
                 step.fun=function(x,t,params,delta.t,...){
-                  with(
-                       as.list(c(x,params)),
-                       rnorm(
-                             n=1,
-                             mean=n+r*n*(1-n/K)*delta.t,
-                             sd=sigma*n*sqrt(delta.t)
-                             )
-                       )
+                  r <- params["r"]
+                  K <- params["K"]
+                  sigma <- params["sigma"]
+                  n <- x["n"]
+                  rnorm(
+                        n=1,
+                        mean=n+r*n*(1-n/K)*delta.t,
+                        sd=sigma*n*sqrt(delta.t)
+                        )
                 },
                 delta.t=0.01
                 ),
               dprocess=onestep.dens(
                 dens.fun=function(x1,x2,t1,t2,params,log,...){
                   delta.t <- t2-t1
-                  with(
-                       as.list(c(x1,params)),
-                       dnorm(
-                             x=x2['n'],
-                             mean=n+r*n*(1-n/K)*delta.t,
-                             sd=sigma*n*sqrt(delta.t),
-                             log=log
-                             )
-                       )
+                  r <- params["r"]
+                  K <- params["K"]
+                  sigma <- params["sigma"]
+                  n <- x1["n"]
+                  dnorm(
+                        x=x2["n"],
+                        mean=n+r*n*(1-n/K)*delta.t,
+                        sd=sigma*n*sqrt(delta.t),
+                        log=log
+                        )
                 }
                 ),
               measurement.model=obs~lnorm(meanlog=log(n),sdlog=log(1+tau)),
               skeleton.type="vectorfield",
               skeleton=function(x,t,params,...){
-                with(
-                     as.list(c(x,params)),
-                     r*n*(1-n/K)
-                     )
+                r <- params["r"]
+                K <- params["K"]
+                n <- x["n"]
+                f <- r*n*(1-n/K)
+                names(f) <- "n"
+                f
               }
               ),
          params=c(
